#

    	sink filter

    	Slide 1:
    		How to install a vegan sink.

    	Step 2:
    		With any type of electro-hydro-mechical work, the recommendation
    		is to:

    			1. 	Wear thick mechanic gloves, like https://amzn.to/4bKX4k6.

    			2. 	Assume every electro-hydro component has batteries
    				and is completelly sentient.

    			3.	Flip the breaker to any hydro-electrical components.

    			4.	Thoroughly research, every hydro-electrical component in
    				the work zone before making any changes.

    				Instruction booklets and Youtube videos are smart places
    				to start.

    			5.	Be careful.

    	Step 3:
    		Install these parts.

    		Tri Clamp 1.5in Fitting:
    			https://amzn.to/3Sz1Msg

    		Tri Clamp Filter:
    			https://amzn.to/3HXT7Lb

    		2 Tri Clamp Ferrule Fittings:
    			https://amzn.to/42JZ5sk

    		EasyDrain 1½" 4-Way Cross Connector:
    			https://amzn.to/3uHUx9l

    		Sink Fitting:
    			https://amzn.to/3I0xmtV

    	Step 9.
    		Once installed, the filter might need to be
    		cleared every once in a while.